@@ -3,8 +3,8 @@
 ;; Copyright (C) 2024-2025 James Cherti | https://www.jamescherti.com/contact/
 
 ;; Author: James Cherti
-;; Package-Version: 20250914.124
-;; Package-Revision: ec339632e0fa
+;; Package-Version: 20251103.1435
+;; Package-Revision: 443d30204c63
 ;; URL: https://github.com/jamescherti/vim-tab-bar.el
 ;; Keywords: frames
 ;; Package-Requires: ((emacs "28.1"))
@@ -297,7 +297,9 @@ ungrouped tabs."
 
 ;;;###autoload
 (define-minor-mode vim-tab-bar-mode
-  "Toggle `vim-tab-bar-mode'."
+  "Emulate the Vim tab bar.
+This styles the tab-bar to emulate Vim's tabbed interface while maintaining
+visual consistency with the currently active theme's color scheme."
   :global t
   :lighter " VimTB"
   :group 'vim-tab-bar
